| A_Data | R Documentation |
Kinematic data for 18 individuals with unilateral above-knee amputations and 42 healthy controls. Each entry contains 18 kinematic variables measured at 1 control data precedes amputee data. Amputee data from Hood et al. (2020); control data from Fukuchi et al. (2018).
A_Data
A list containing the 18 kinematic variables with each list containing a data.frame with N rows and T variables, where N is the total number of subjects and T is the total number of time points.
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
Internal gait study
# Load the Data
data(A_Data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.