| A_DataL | R Documentation |
Kinematic data for 18 individuals with unilateral above-knee amputations (left side only) and 42 healthy controls. Each entry includes pelvic, hip, knee, ankle, and foot angles, sampled at 1 over the full gait cycle. Amputee data from Hood et al. (2020); control data from Fukuchi et al. (2018).
A_DataL
A list containing the 9 kinematic variables with each list containing a data.frame with N rows and T variables, where N is the total number of subjects and T is the total number of time points.
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
# Load the Data
data(A_DataL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.