| P_Data | R Documentation |
Kinematic data for Parkinson's subjects.The PD dataset is publicly accessible, as detailed in Shida, T. K. F., Costa, T. M., de Oliveira, C. E. N., de Castro Treza, R., Hondo, S. M., Los Angeles, E., ... & Coelho, D. B. (2023).. It includes data from 21 right-handed idiopathic PD individuals. Measurements are taken at 1
P_Data
A list containing the 18 kinematic variables with each list containing a data.frame with N rows and T variables, where N is the total number of subjects and T is the total number of time points.
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
numeric data.frame with N rows and T variables
# Load the Data
data(P_Data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.