plot_gait_comparison: Plot Gait Curves with FGDI Overlay

View source: R/plot_gait_comparison.R

plot_gait_comparisonR Documentation

Plot Gait Curves with FGDI Overlay

Description

Plots gait curves comparing healthy controls to individuals with highest deviation.

Usage

plot_gait_comparison(joint_index, title, FGDI, Data, ID, combined)

Arguments

joint_index

Index of the joint angle to plot.

title

Title for the plot.

FGDI

Output list from FGDI() function.

Data

List of matrices containing the gait data.

ID

Subject group labels.

combined

Logical indicating if you want to see the combined FGDI results (TRUE). This approach yields a measure of severity by collectively considering both legs, and displays the maximum gait abnormality. If FALSE the max gait pathology is displayed for each leg individually left in green and right in blue.

Value

A ggplot object.

Examples

data(A_Data)
data(A_data_info)
ID <- c(rep("Case", 18), rep("Control", 42))
fgdi_out <- FGDI(A_Data, ID, PVE_I = 0.99)
plot_gait_comparison(1, "Pelvis Tilt", fgdi_out, A_Data, ID, combined=FALSE)

fgdiR documentation built on Dec. 16, 2025, 5:07 p.m.